How To Find Interquartile Range - UpSkillMe
Author: UpSkillMe Staff
Description: The interquartile range is the difference between the third and the first quartiles. Here is how to find the Interquartile Range.
Date: 2020-09-19T23:44:28+00:00

Skip to content
September 19, 2020 How-Tos / Math

# How To Find Interquartile Range

Posted by UpSkillMe Staff

Image Credits: Pinterest.

The interquartile range (IQR) is the difference between the third and the first quartiles. It is a measure of dispersion. Quartiles are the values that divide a list of numbers into quarters. Here is how to find the Interquartile Range.

The interquartile range formula is the first quartile subtracted from the third quartile:

## How To Find Interquartile Range for an Odd Set of Numbers

1. Order the numbers from least to greatest.

   Given Data Set: 5, 7, 9, 3, 13, 11, 17, 15, 21, 19, 23

   Order Number: 3, 5, 7, 9, 11, 13, 15, 17, 19, 21, 23.

2. Find the median. The median is the data value in the middle of the set. The median in the given data set is 13 since 13 is in the middle of the set.

   Median: 3, 5, 7, 9, 11, 13, 15, 17, 19, 21, 23

3. Place the parentheses around the numbers before and after the median. It makes Q1 and Q3 easier to spot.

   (3, 5, 7, 9, 11), 13, (15, 17, 19, 21, 23)

4. Find the median of both the lower and upper half of the data. Think Q1 as a median in the lower half of the data and Q3 as a median for the upper half of data.

   (3, 5, 7, 9, 11) = 7 = Q1 and (15, 17, 19, 21, 23) = 19 = Q3

5. Subtract Q1 from Q3 to find the interquartile range

   Q3 – Q1 = 19 – 7 = 12

## How To Find Interquartile Range for an Even Set of Numbers

1. Order the numbers from least to greatest.

   Given Data Set: 42, 51, 62, 47, 38, 50, 54, 43

   Order Number: 38, 42, 43, 47, 50, 51, 54, 62.

2. Make a mark in the center of the data:

   Median: 38, 42, 43, 47,| 50, 51, 54, 62

3. Place the parentheses around the numbers before and after the median. It makes Q1 and Q3 easier to spot.

   (38, 42, 43, 47),| (50, 51, 54, 62).

4. Find the median. We have the even data sets so the median is the average of the middle two numbers.

   (38, 42, 43, 47) =
   = Q1

   (50, 51, 54, 62) =
   = Q3

5. Subtract Q1 from Q3 to find the interquartile range.

   Q3 – Q1 = 52.5 – 42.5 = 10

### Related

By using this site, you agree with our use of cookies. Accept Reject
Privacy & Cookies Policy

#### Privacy Overview

This website uses cookies to improve your experience while you navigate through the website. Out of these cookies, the cookies that are categorized as necessary are stored on your browser as they are essential for the working of basic functionalities of the website. We also use third-party cookies that help us analyze and understand how you use this website. These cookies will be stored in your browser only with your consent. You also have the option to opt-out of these cookies. But opting out of some of these cookies may have an effect on your browsing experience.
Necessary
Necessary
Always Enabled
Necessary cookies are absolutely essential for the website to function properly. This category only includes cookies that ensures basic functionalities and security features of the website. These cookies do not store any personal information.